@@ -5,7 +5,7 @@ use serde::Deserialize;
 use serde::Serialize;
 
 lazy_static! {
-  static ref JS_DOC_TAG_MAYBE_DOC_RE: Regex = Regex::new(r#"^\s*@(deprecated)(?:\s+(.+))?"#).unwrap();
+  static ref JS_DOC_TAG_MAYBE_DOC_RE: Regex = Regex::new(r#"(?s)^\s*@(deprecated)(?:\s+(.+))?"#).unwrap();
   static ref JS_DOC_TAG_NAMED_RE: Regex = Regex::new(r#"(?s)^\s*@(callback|template)\s+([a-zA-Z_$]\S*)(?:\s+(.+))?"#).unwrap();
   static ref JS_DOC_TAG_NAMED_TYPED_RE: Regex = Regex::new(r#"(?s)^\s*@(prop(?:erty)?|typedef)\s+\{([^}]+)\}\s+([a-zA-Z_$]\S*)(?:\s+(.+))?"#).unwrap();
   static ref JS_DOC_TAG_ONLY_RE: Regex = Regex::new(r#"^\s*@(constructor|class|module|public|private|protected|readonly)"#).unwrap();
@@ -13,7 +13,7 @@ lazy_static! {
     r#"(?s)^\s*@(?:param|arg(?:ument)?)(?:\s+\{([^}]+)\})?\s+([a-zA-Z_$]\S*)(?:\s+(.+))?"#
   )
   .unwrap();
-  static ref JS_DOC_TAG_RE: Regex = Regex::new(r#"^\s*@\S+"#).unwrap();
+  static ref JS_DOC_TAG_RE: Regex = Regex::new(r#"(?s)^\s*@\S+"#).unwrap();
   static ref JS_DOC_TAG_RETURN_RE: Regex = Regex::new(r#"(?s)^\s*@returns?(?:\s+\{([^}]+)\})?(?:\s+(.+))?"#).unwrap();
   static ref JS_DOC_TAG_TYPED_RE: Regex = Regex::new(r#"(?s)^\s*@(enum|extends|augments|this|type)\s+\{([^}]+)\}(?:\s+(.+))?"#).unwrap();
 }
@@ -277,27 +277,31 @@ mod tests {
   #[test]
   fn test_js_doc_tag_named() {
     assert_eq!(
-      serde_json::to_value(JsDoc::from("@callback name more docs".to_string()))
-        .unwrap(),
+      serde_json::to_value(JsDoc::from(
+        "@callback name more docs\n\nnew paragraph".to_string()
+      ))
+      .unwrap(),
       json!({
         "tags": [
           {
             "kind": "callback",
             "name": "name",
-            "doc": "more docs",
+            "doc": "more docs\n\nnew paragraph",
           }
         ]
       })
     );
     assert_eq!(
-      serde_json::to_value(JsDoc::from("@template T more docs".to_string()))
-        .unwrap(),
+      serde_json::to_value(JsDoc::from(
+        "@template T more docs\n\nnew paragraph".to_string()
+      ))
+      .unwrap(),
       json!({
         "tags": [
           {
             "kind": "template",
             "name": "T",
-            "doc": "more docs",
+            "doc": "more docs\n\nnew paragraph",
           }
         ]
       })
@@ -307,61 +311,67 @@ mod tests {
   #[test]
   fn test_js_doc_tag_typed() {
     assert_eq!(
-      serde_json::to_value(JsDoc::from("@enum {string} more doc".to_string()))
-        .unwrap(),
+      serde_json::to_value(JsDoc::from(
+        "@enum {string} more doc\n\nnew paragraph".to_string()
+      ))
+      .unwrap(),
       json!({
         "tags": [{
           "kind": "enum",
           "type": "string",
-          "doc": "more doc"
+          "doc": "more doc\n\nnew paragraph"
         }]
       })
     );
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@extends {string} more doc".to_string()
+        "@extends {string} more doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
         "tags": [{
           "kind": "extends",
           "type": "string",
-          "doc": "more doc"
+          "doc": "more doc\n\nnew paragraph"
         }]
       })
     );
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@augments {string} more doc".to_string()
+        "@augments {string} more doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
         "tags": [{
           "kind": "extends",
           "type": "string",
-          "doc": "more doc"
+          "doc": "more doc\n\nnew paragraph"
         }]
       })
     );
     assert_eq!(
-      serde_json::to_value(JsDoc::from("@this {string} more doc".to_string()))
-        .unwrap(),
+      serde_json::to_value(JsDoc::from(
+        "@this {string} more doc\n\nnew paragraph".to_string()
+      ))
+      .unwrap(),
       json!({
         "tags": [{
           "kind": "this",
           "type": "string",
-          "doc": "more doc"
+          "doc": "more doc\n\nnew paragraph"
         }]
       })
     );
     assert_eq!(
-      serde_json::to_value(JsDoc::from("@type {string} more doc".to_string()))
-        .unwrap(),
+      serde_json::to_value(JsDoc::from(
+        "@type {string} more doc\n\nnew paragraph".to_string()
+      ))
+      .unwrap(),
       json!({
         "tags": [{
           "kind": "type",
           "type": "string",
-          "doc": "more doc"
+          "doc": "more doc\n\nnew paragraph"
         }]
       })
     );
@@ -371,7 +381,7 @@ mod tests {
   fn test_js_doc_tag_named_typed() {
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@prop {string} a more doc".to_string()
+        "@prop {string} a more doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
@@ -379,13 +389,13 @@ mod tests {
           "kind": "property",
           "name": "a",
           "type": "string",
-          "doc": "more doc"
+          "doc": "more doc\n\nnew paragraph"
         }]
       })
     );
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@property {string} a more doc".to_string()
+        "@property {string} a more doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
@@ -393,13 +403,13 @@ mod tests {
           "kind": "property",
           "name": "a",
           "type": "string",
-          "doc": "more doc"
+          "doc": "more doc\n\nnew paragraph"
         }]
       })
     );
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@typedef {object} Interface more doc".to_string()
+        "@typedef {object} Interface more doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
@@ -407,7 +417,7 @@ mod tests {
           "kind": "typedef",
           "name": "Interface",
           "type": "object",
-          "doc": "more doc"
+          "doc": "more doc\n\nnew paragraph"
         }]
       })
     );
@@ -424,12 +434,14 @@ mod tests {
       })
     );
     assert_eq!(
-      serde_json::to_value(JsDoc::from("@deprecated maybe doc".to_string()))
-        .unwrap(),
+      serde_json::to_value(JsDoc::from(
+        "@deprecated maybe doc\n\nnew paragraph".to_string()
+      ))
+      .unwrap(),
       json!({
         "tags": [{
           "kind": "deprecated",
-          "doc": "maybe doc",
+          "doc": "maybe doc\n\nnew paragraph",
         }]
       })
     );
@@ -438,19 +450,21 @@ mod tests {
   #[test]
   fn test_js_doc_tag_param() {
     assert_eq!(
-      serde_json::to_value(JsDoc::from("@param a maybe doc".to_string()))
-        .unwrap(),
+      serde_json::to_value(JsDoc::from(
+        "@param a maybe doc\n\nnew paragraph".to_string()
+      ))
+      .unwrap(),
       json!({
         "tags": [{
           "kind": "param",
           "name": "a",
-          "doc": "maybe doc",
+          "doc": "maybe doc\n\nnew paragraph",
         }]
       })
     );
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@param {string} a maybe doc".to_string()
+        "@param {string} a maybe doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
@@ -458,7 +472,7 @@ mod tests {
           "kind": "param",
           "name": "a",
           "type": "string",
-          "doc": "maybe doc",
+          "doc": "maybe doc\n\nnew paragraph",
         }]
       })
     );
@@ -475,7 +489,7 @@ mod tests {
     );
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@arg {string} a maybe doc".to_string()
+        "@arg {string} a maybe doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
@@ -483,13 +497,13 @@ mod tests {
           "kind": "param",
           "name": "a",
           "type": "string",
-          "doc": "maybe doc",
+          "doc": "maybe doc\n\nnew paragraph",
         }]
       })
     );
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@argument {string} a maybe doc".to_string()
+        "@argument {string} a maybe doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
@@ -497,7 +511,7 @@ mod tests {
           "kind": "param",
           "name": "a",
           "type": "string",
-          "doc": "maybe doc",
+          "doc": "maybe doc\n\nnew paragraph",
         }]
       })
     );
@@ -507,37 +521,39 @@ mod tests {
   fn test_js_doc_tag_returns() {
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@return {string} maybe doc".to_string()
+        "@return {string} maybe doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
         "tags": [{
           "kind": "return",
           "type": "string",
-          "doc": "maybe doc",
-        }]
-      })
-    );
-    assert_eq!(
-      serde_json::to_value(JsDoc::from("@return maybe doc".to_string()))
-        .unwrap(),
-      json!({
-        "tags": [{
-          "kind": "return",
-          "doc": "maybe doc",
+          "doc": "maybe doc\n\nnew paragraph",
         }]
       })
     );
     assert_eq!(
       serde_json::to_value(JsDoc::from(
-        "@returns {string} maybe doc".to_string()
+        "@return maybe doc\n\nnew paragraph".to_string()
+      ))
+      .unwrap(),
+      json!({
+        "tags": [{
+          "kind": "return",
+          "doc": "maybe doc\n\nnew paragraph",
+        }]
+      })
+    );
+    assert_eq!(
+      serde_json::to_value(JsDoc::from(
+        "@returns {string} maybe doc\n\nnew paragraph".to_string()
       ))
       .unwrap(),
       json!({
         "tags": [{
           "kind": "return",
           "type": "string",
-          "doc": "maybe doc",
+          "doc": "maybe doc\n\nnew paragraph",
         }]
       })
     );
